=====================================================
 ``amqp.transport``
=====================================================

.. contents::
    :local:
.. currentmodule:: amqp.transport

.. automodule:: amqp.transport

.. autoclass:: _AbstractTransport
    :members:
    :undoc-members:

.. autoclass:: SSLTransport
    :members:
    :private-members: _wrap_context, _wrap_socket_sni
    :undoc-members:

.. autoclass:: TCPTransport
    :members:
    :undoc-members:

.. autoclass:: Transport
    :members:
    :undoc-members:
